@@ -126,9 +126,10 @@ class Connection(object):
         except Exception as err:
             raise RqlDriverError("Could not connect to %s:%s. Error: %s" % (self.host, self.port, err))
 
-        self._sock_sendall(struct.pack("<L", p.VersionDummy.Version.V0_3))
-        self._sock_sendall(struct.pack("<L", len(self.auth_key)) + str.encode(self.auth_key, 'ascii'))
-        self._sock_sendall(struct.pack("<L", p.VersionDummy.Protocol.JSON))
+        self._sock_sendall(struct.pack("<LL", p.VersionDummy.Version.V0_3, \
+                                              len(self.auth_key)) + \
+                           str.encode(self.auth_key, 'ascii') + \
+                           struct.pack("<L", p.VersionDummy.Protocol.JSON))
 
         # Read out the response from the server, which will be a null-terminated string
         response = b""
